/****************************************************************************
** Meta object code from reading C++ file 'browserrun.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../kparts-5.116.0/src/browserrun.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'browserrun.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KParts__BrowserRun_t {
    QByteArrayData data[9];
    char stringdata0[114];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KParts__BrowserRun_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KParts__BrowserRun_t qt_meta_stringdata_KParts__BrowserRun = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KParts::BrowserRun"
QT_MOC_LITERAL(1, 19, 23), // "slotBrowserScanFinished"
QT_MOC_LITERAL(2, 43, 0), // ""
QT_MOC_LITERAL(3, 44, 5), // "KJob*"
QT_MOC_LITERAL(4, 50, 3), // "job"
QT_MOC_LITERAL(5, 54, 19), // "slotBrowserMimetype"
QT_MOC_LITERAL(6, 74, 9), // "KIO::Job*"
QT_MOC_LITERAL(7, 84, 4), // "type"
QT_MOC_LITERAL(8, 89, 24) // "slotCopyToTempFileResult"

    },
    "KParts::BrowserRun\0slotBrowserScanFinished\0"
    "\0KJob*\0job\0slotBrowserMimetype\0KIO::Job*\0"
    "type\0slotCopyToTempFileResult"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KParts__BrowserRun[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   29,    2, 0x09 /* Protected */,
       5,    2,   32,    2, 0x09 /* Protected */,
       8,    1,   37,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 6, QMetaType::QString,    4,    7,
    QMetaType::Void, 0x80000000 | 3,    4,

       0        // eod
};

void KParts::BrowserRun::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BrowserRun *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->slotBrowserScanFinished((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        case 1: _t->slotBrowserMimetype((*reinterpret_cast< KIO::Job*(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 2: _t->slotCopyToTempFileResult((*reinterpret_cast< KJob*(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject KParts::BrowserRun::staticMetaObject = { {
    QMetaObject::SuperData::link<KRun::staticMetaObject>(),
    qt_meta_stringdata_KParts__BrowserRun.data,
    qt_meta_data_KParts__BrowserRun,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *KParts::BrowserRun::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KParts::BrowserRun::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KParts__BrowserRun.stringdata0))
        return static_cast<void*>(this);
    return KRun::qt_metacast(_clname);
}

int KParts::BrowserRun::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KRun::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
